/**
 * Implementation of the Stack interface using a fixed-length array.
 * An exception is thrown if a push operation is attempted when the
 * size of the stack is equal to the length of the array.
 * 
 * @author Natasha Gelfand
 * @author Roberto Tamassia
 * @author JP Vergara - simplified some portions
 * @see FullStackException
 */

public class ArrayStack implements Stack
{

	public static final int CAPACITY = 1000;
	private Object S[];
	private int top;

	public ArrayStack()
	{
		S = new Object[CAPACITY];
		top = -1;
	}

	public int size()
	{ 
		return (top + 1);
	}
	
	public boolean isEmpty()
	{
		return (top < 0);
	}

	public void push(Object obj) throws FullStackException
	{
		if (size() == CAPACITY)
			throw new FullStackException();
		S[++top] = obj;
	}

	public Object top() throws EmptyStackException
	{
		if (isEmpty())
			throw new EmptyStackException();
		return S[top];
	}

	public Object pop() throws EmptyStackException
	{
		Object elem;
		if (isEmpty())
			throw new EmptyStackException();
		elem = S[top];
		S[top--] = null; // dereference S[top] for garbage collection.
		return elem;
	}
	
}
